@@ -322,6 +322,10 @@ class Schema(object):
         except KeyError:
             raise AttributeError("No {} field in schema {}".format(name, self.table_name))
 
+    def has_field(self, field_name):
+        """Return True if schema contains field_name"""
+        return field_name in self.lookup["names"]
+
     def set_field(self, field_name, field):
         if not field_name: raise ValueError("field_name is empty")
         if field_name in self.fields: raise ValueError("{} already exists and cannot be changed".format(field_name))
@@ -687,7 +691,7 @@ class _Field(object):
     def set_type(self, field_type):
         """Try to infer as much about the type as can be inferred at this moment
 
-        Because the Field support string classpaths (eg, "modname.Classname") we can't
+        Because the Field supports string classpaths (eg, "modname.Classname") we can't
         figure everything out in this method, so we figure out as much as we can
         and then defer everything else to the .interface_type and .schema properties, this
         allows the parser to hopefully finish loading the modules before we have to
